@@ -1,6 +1,5 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-'''preggy core assertion class.
+'''preggy core classes: `Assertions` and `Expect`.
 '''
 # preggy assertions
 # https://github.com/heynemann/preggy
@@ -12,7 +11,7 @@
 import re
 
 
-class Assertions:
+class Assertions(object):
     registered_assertions = {}
 
     @classmethod
@@ -25,7 +24,7 @@ class Assertions:
         raise a `AssertionError`.
 
         By raising a `AssertionError`, you get the benefit of highlighting
-        the important values when your vows are broken.
+        the important values when your tests are broken.
 
         If you still just wanna raise an `AssertionError` like old times,
         that’s supported, too.
@@ -87,12 +86,12 @@ class Assertions:
         def exec_assertion(*args):
             raw_msg = _assertion_msg(humanized_method_name, *args)
             if not method(*args):
-                raise AssertionError(raw_msg, *args)
+                raise AssertionError(raw_msg.format(*args))
 
         def exec_not_assertion(*args):
             raw_msg = _assertion_msg('not {0}'.format(humanized_method_name), *args)
             if method(*args):
-                raise AssertionError(raw_msg, *args)
+                raise AssertionError(raw_msg.format(*args))
 
         Assertions.registered_assertions[method.__name__] = exec_assertion
         Assertions.registered_assertions['not_{method_name}'.format(method_name=method.__name__)] = exec_not_assertion
@@ -117,21 +116,24 @@ class Expect(object):
         self.not_assert = False
 
     def __getattr__(self, name):
+        # common cases
         if name == 'topic':
             return super(Expect, self).__getattr__(name)
-
         if name == 'Not':
             self.not_assert = not self.not_assert
             return self
 
+        # update `not_` assertions
         if self.not_assert:
             method_name = 'not_{name}'.format(name=name)
         else:
             method_name = name
 
-        if not method_name in Assertions.registered_assertions:
+        # check for unregistered assertions
+        if method_name not in Assertions.registered_assertions:
             raise AttributeError('Assertion {method_name} was not found!'.format(method_name=method_name))
 
+        # if program gets this far, then it’s time to perform the assertion. (...FINALLY! ;D)
         def assert_topic(*args, **kw):
             '''Allows instances (topics) to chain calls to `Assertion`s.
 
@@ -140,7 +142,7 @@ class Expect(object):
                 expect(topic).to_be_True()
 
             ...This method is what allows `expect(topic)` to call
-            `.to_be_True()` (or some other VowsAssertion).
+            `.to_be_True()` (or some other Assertion).
 
             '''
             return Assertions.registered_assertions[method_name](self.topic, *args, **kw)
