@@ -23,9 +23,9 @@ def to_equal(topic, expected):
     '''Asserts that `topic == expected`.'''
 
     if isinstance(topic, (six.binary_type, )):
-        topic = topic.encode('utf-8')
+        topic = topic.decode('utf-8')
 
     if isinstance(expected, (six.binary_type, )):
-        expected = expected.encode('utf-8')
+        expected = expected.decode('utf-8')
 
     return expected == topic
